#!/bin/bash

# Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: MIT-0
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this
# software and associated documentation files (the "Software"), to deal in the Software
# without restriction, including without limitation the rights to use, copy, modify,
# merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

# send_dcvsessionready_notification.sh script to send a notification by email using AWS SNS
exec 2>"/var/log/send-notification.log"

if [ "$AWS" == "1" ] ; then
    export AWS_REGION=$(curl -s http://169.254.169.254/latest/dynamic/instance-identity/document | jq -r .region)
    export AWS_DEFAULT_REGION=${AWS_REGION}
    set -x
    _msg_already_sent="/var/run/dcv_msg_sent"
    _ip_address="$(curl -s http://checkip.amazonaws.com)"
    _region="$(curl -s http://169.254.169.254/latest/dynamic/instance-identity/document | jq -r .region)"
    _subject="DCV Session is ready."
    _message="
Dear User,
your DCV session is ready.
Please connect to https://${_ip_address}:8443
and login with your credentials.
Thanks,
Best Regards.
"
else
    :
fi
# wait dcv session is started
while true; do
    ps -ef | grep Xdcv | grep xauth 2>&1 >/dev/null && break
    sleep 2
done
if [ "$AWS" == "1" ] ; then
    _topic_arn="$(/usr/local/bin/aws secretsmanager get-secret-value \
                                 --secret-id dcv-session-ready-notifycation \
                                 --query SecretString  --output text 2>/dev/null)"
    if [ -n "${_topic_arn}" ] ; then
	# publish the notification
	if [ ! -r "${_msg_already_sent}" ] ; then
	    /usr/local/bin/aws sns publish --message "${_message}" \
                       --subject "DCV Session is ready!" \
                       --topic-arn "${_topic_arn}" \
                       --region "${_region}" && touch "${_msg_already_sent}"
	fi
    fi
else
    echo "Message can be sent here ..."
fi
